.. :changelog:

History
-------

0.0.1 (08-10-2020)
---------------------

* First code creation


0.1.0 (26-03-2021)
------------------

* heavily refactored: created new modules (windows.py, application.py, and logging.py), created new class Effect() in Items.py, updated README, the two main attributes in CanvasFrame() renamed to canvas_landscape and canvas_status.
